@@ -16,7 +16,6 @@ import { Widget } from '@lumino/widgets';
 
 function createGist(path: string) {
   return new Promise((resolve, reject) => {
-    console.log('creating gist');
     const setting = ServerConnection.makeSettings();
     const url = URLExt.join(setting.baseUrl, '/github/share-gist');
     ServerConnection.makeRequest(
@@ -24,13 +23,18 @@ function createGist(path: string) {
       { method: 'POST', body: JSON.stringify({ path }) },
       setting
     ).then((response: any) => {
-      response.json().then((gist: any) => {
-        if (gist.html_url) {
-          resolve(gist.html_url);
-        } else {
-          reject(gist.error);
-        }
-      });
+      response
+        .json()
+        .then((gist: any) => {
+          if (gist.html_url) {
+            resolve(gist.html_url);
+          } else {
+            reject(gist.error);
+          }
+        })
+        .catch((err: any) => {
+          console.log(err);
+        });
     });
   });
 }
@@ -80,27 +84,18 @@ export function addShareGistCommand(
                     `toolbar=no,scrollbars=yes,resizable=yes,top=${popup_y_position},left=${popup_x_position},width=${popup_width},height=${popup_height}`
                   );
                   (function (popup) {
-                    window.addEventListener(
-                      'message',
-                      event => {
-                        // browser is disabled
-                        // hideGitHubSignInButton();
-                        // showGitHubFilebrowser();
-                        popup!.close();
-                        // hide sign-in button
-                        // this._launchBinderButton.addClass(INVISIBLE);
-                        // show user their github account
-                        // gitHubBrowser.userName.name.set(event.data); // need github filebrowser
-                        createGist(path).then((gist_url: any) => {
-                          showDialog({
-                            title: 'Your gist is now available on GitHub:',
-                            body: new Private.GistLink(gist_url),
-                            buttons: [Dialog.okButton({ label: 'Dismiss' })]
-                          });
+                    const eventListener = (event: any) => {
+                      popup!.close();
+                      window.removeEventListener('message', eventListener);
+                      createGist(path).then((gist_url: any) => {
+                        showDialog({
+                          title: 'Your gist is now available on GitHub:',
+                          body: new Private.GistLink(gist_url),
+                          buttons: [Dialog.okButton({ label: 'Dismiss' })]
                         });
-                      },
-                      false
-                    );
+                      });
+                    };
+                    window.addEventListener('message', eventListener, false);
                   })(popup);
                 }
               });
